@@ -46,7 +46,8 @@ pref("network.search.url","http://cgi.netscape.com/cgi-bin/url_search.cgi?search
 pref("keyword.URL", "http://keyword.netscape.com/keyword/");
 pref("keyword.enabled", false);
 pref("general.useragent.locale", "chrome://navigator/locale/navigator.properties");
-pref("general.useragent.misc", "rv:1.0.0+");
+pref("general.useragent.contentlocale", "chrome://navigator-region/locale/region.properties");
+pref("general.useragent.misc", "rv:1.4.2");
 
 pref("general.startup.browser",             true);
 pref("general.startup.mail",                false);
@@ -63,15 +64,17 @@ pref("backups.number_of_prefs_copies", 1);
 // 0 = blank, 1 = home (browser.startup.homepage), 2 = last
 pref("browser.startup.page",                1);
 pref("browser.startup.homepage",	   "chrome://navigator-region/locale/region.properties");
+pref("browser.startup.homepage.count", 1);
 // "browser.startup.homepage_override" was for 4.x
 pref("browser.startup.homepage_override.1", true);
 pref("browser.startup.autoload_homepage",   true);
 
 pref("browser.cache.enable",                true); // see also network.http.use-cache
 pref("browser.cache.disk.enable",           true);
-pref("browser.cache.disk.capacity",         50000);
+pref("browser.cache.disk.capacity",         51200);
 pref("browser.cache.memory.enable",         true);
-pref("browser.cache.memory.capacity",       4096);
+//pref("browser.cache.memory.capacity",     -1);
+// -1 = determine dynamically, 0 = none, n = memory capacity in kilobytes
 pref("browser.cache.disk_cache_ssl",        false);
 // 0 = once-per-session, 1 = each-time, 2 = never, 3 = when-appropriate/automatically
 pref("browser.cache.check_doc_frequency",   3);
@@ -91,6 +94,7 @@ pref("browser.anchor_color",                "#0000EE");
 pref("browser.visited_color",               "#551A8B");
 pref("browser.underline_anchors",           true);
 pref("browser.blink_allowed",               true);
+pref("browser.enable_automatic_image_resizing", false);
 
 pref("browser.display.use_focus_colors",    false);
 pref("browser.display.focus_background_color", "#117722");
@@ -98,9 +102,6 @@ pref("browser.display.focus_text_color",     "#ffffff");
 pref("browser.display.focus_ring_width",     1);
 pref("browser.display.focus_ring_on_anything", false);
 
-pref("browser.new_find", true);  // temporary
-pref("editor.new_find",  true);  // temporary
-
 pref("browser.urlbar.autoFill", false);
 pref("browser.urlbar.showPopup", true);
 pref("browser.urlbar.showSearch", true);
@@ -110,13 +111,12 @@ pref("browser.chrome.site_icons", true);
 pref("browser.chrome.favicons", false);
 
 pref("browser.chrome.toolbar_tips",         true);
+// 0 = Pictures Only, 1 = Text Only, 2 = Pictures and Text
 pref("browser.chrome.toolbar_style",        2);
 
 pref("browser.toolbars.showbutton.bookmarks", true);
 pref("browser.toolbars.showbutton.go",      false);
 pref("browser.toolbars.showbutton.home",    true);
-pref("browser.toolbars.showbutton.mynetscape", true);
-pref("browser.toolbars.showbutton.net2phone", true);
 pref("browser.toolbars.showbutton.print",   true);
 pref("browser.toolbars.showbutton.search",  true);
 
@@ -128,15 +128,31 @@ pref("browser.helperApps.neverAsk.openFile", "");
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
+// Tab focus model bit field:
+// 1 focuses text controls, 2 focuses other form elements, 4 adds links.
+// Most users will want 1, 3, or 7.
+pref("accessibility.tabfocus", 7);
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
 pref("accessibility.accesskeycausesactivation", true);
 
+// Type Ahead Find
+pref("accessibility.typeaheadfind", true);
+pref("accessibility.typeaheadfind.autostart", true);
+pref("accessibility.typeaheadfind.linksonly", true);
+pref("accessibility.typeaheadfind.startlinksonly", false);
+pref("accessibility.typeaheadfind.timeout", 4000);
+pref("accessibility.typeaheadfind.enabletimeout", true);
+pref("accessibility.typeaheadfind.soundURL", "default");
+pref("accessibility.typeaheadfind.enablesound", true);
+
 // Dialog modality issues
 pref("browser.prefWindowModal", true);
 pref("browser.show_about_as_stupid_modal_window", false);
 
 pref("browser.download.progressDnldDialog.keepAlive", true); // keep the dnload progress dialog up after dnload is complete
+pref("browser.download.progressDnldDialog.enable_launch_reveal_buttons", true);
+pref("browser.download.progressDnlgDialog.dontAskForLaunch", false);
 
 // various default search settings
 pref("browser.search.defaulturl", "chrome://navigator-region/locale/region.properties");
@@ -149,8 +165,9 @@ pref("browser.search.powermode", 0);
 pref("browser.search.basic.min_ver", "0.0");
 pref("browser.urlbar.autocomplete.enabled", true);
 pref("browser.urlbar.clickSelectsAll", true);
+// when clickSelectsAll=true, does it also apply when the click is past end of text?
+pref("browser.urlbar.clickAtEndSelects", true);
 
-pref("browser.history.last_page_visited", "");
 pref("browser.history_expire_days", 9);
 pref("browser.history.grouping", "day");
 pref("browser.sessionhistory.max_entries", 50);
@@ -175,23 +192,25 @@ pref("browser.forms.submit.backwards_compatible", true);
 
 // Tab browser preferences.
 pref("browser.tabs.autoHide", true);
+pref("browser.tabs.forceHide", false);
 pref("browser.tabs.loadInBackground", false);
 pref("browser.tabs.opentabfor.middleclick", false);
 pref("browser.tabs.opentabfor.urlbar", false);
 pref("browser.tabs.opentabfor.windowopen", false);
 pref("browser.tabs.opentabfor.bookmarks", false);
 
+// lets new tab/window load something different than first window
+// -1 - use navigator startup preference
+//  0 - loads blank page
+//  1 - loads home page
+//  2 - loads last page visited
+pref("browser.tabs.loadOnNewTab", 0);
+pref("browser.windows.loadOnNewWindow", 1);
+
 // view source
 pref("view_source.syntax_highlight", true);
 pref("view_source.wrap_long_lines", false);
 
-// gfx widgets
-pref("nglayout.widget.mode", 2);
-pref("nglayout.widget.gfxscrollbars", true);
-
-// css2 hover pref
-pref("nglayout.events.showHierarchicalHover", false);
-
 // dispatch left clicks only to content in browser (still allows clicks to chrome/xul)
 pref("nglayout.events.dispatchLeftClickOnly", true);
 
@@ -216,6 +235,9 @@ pref("browser.fixup.alternate.enabled", true);
 pref("browser.fixup.alternate.prefix", "www.");
 pref("browser.fixup.alternate.suffix", ".com");
 
+// Bookmarks prefs
+pref("browser.bookmarks.confirm_sorting", true);
+
 //Internet Search
 pref("browser.search.defaultenginename", "chrome://communicator-region/locale/region.properties");
 
@@ -263,7 +285,6 @@ pref("print.print_edge_bottom", 0); // 1/100 of an inch
 //pref("capability.policy.default.barprop.visible.set", "UniversalBrowserWrite");
 
 pref("capability.policy.default_policynames", "mailnews");
-pref("capability.policy.policynames", "");
 
 pref("capability.policy.default.DOMException.code", "allAccess");
 pref("capability.policy.default.DOMException.message", "allAccess");
@@ -282,8 +303,6 @@ pref("capability.policy.default.History.toString", "UniversalBrowserRead");
 
 pref("capability.policy.default.HTMLDocument.close", "allAccess");
 pref("capability.policy.default.HTMLDocument.open", "allAccess");
-pref("capability.policy.default.HTMLDocument.write", "allAccess");
-pref("capability.policy.default.HTMLDocument.writeln", "allAccess");
 
 pref("capability.policy.default.Location.hash.set", "allAccess");
 pref("capability.policy.default.Location.href.set", "allAccess");
@@ -301,7 +320,6 @@ pref("capability.policy.default.Window.Components", "allAccess");
 pref("capability.policy.default.Window.document", "allAccess");
 pref("capability.policy.default.Window.focus", "allAccess");
 pref("capability.policy.default.Window.frames", "allAccess");
-pref("capability.policy.default.Window.fullScreen", "noAccess");
 pref("capability.policy.default.Window.history", "allAccess");
 pref("capability.policy.default.Window.length", "allAccess");
 pref("capability.policy.default.Window.location", "allAccess");
@@ -318,7 +336,9 @@ pref("capability.policy.mailnews.*.attributes.get", "noAccess");
 pref("capability.policy.mailnews.*.baseURI.get", "noAccess");
 pref("capability.policy.mailnews.*.data.get", "noAccess");
 pref("capability.policy.mailnews.*.getAttribute", "noAccess");
+pref("capability.policy.mailnews.*.getAttributeNS", "noAccess");
 pref("capability.policy.mailnews.*.getNamedItem", "noAccess");
+pref("capability.policy.mailnews.*.getNamedItemNS", "noAccess");
 pref("capability.policy.mailnews.*.host.get", "noAccess");
 pref("capability.policy.mailnews.*.hostname.get", "noAccess");
 pref("capability.policy.mailnews.*.href.get", "noAccess");
@@ -351,17 +371,104 @@ pref("capability.policy.mailnews.Window.resizeTo", "noAccess");
 pref("capability.policy.mailnews.Window.screenX.set", "noAccess");
 pref("capability.policy.mailnews.Window.screenY.set", "noAccess");
 pref("capability.policy.mailnews.Window.sizeToContent", "noAccess");
+pref("capability.policy.mailnews.document.load", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.channel", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.responseXML", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.responseText", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.status", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.statusText", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.abort", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.getAllResponseHeaders", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.getResponseHeader", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.open", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.send", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.setRequestHeader", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.readyState", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.overrideMimeType", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.onload", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.onerror", "noAccess");
+pref("capability.policy.mailnews.XMLHttpRequest.onreadystatechange", "noAccess");
+pref("capability.policy.mailnews.XMLSerializer.serializeToString", "noAccess");
+pref("capability.policy.mailnews.XMLSerializer.serializeToStream", "noAccess");
+pref("capability.policy.mailnews.DOMParser,parseFromString", "noAccess");
+pref("capability.policy.mailnews.DOMParser,parseFromStream", "noAccess");
+pref("capability.policy.mailnews.SOAPCall.transportURI", "noAccess");
+pref("capability.policy.mailnews.SOAPCall.verifySourceHeader", "noAccess");
+pref("capability.policy.mailnews.SOAPCall.invoke", "noAccess");
+pref("capability.policy.mailnews.SOAPCall.asyncInvoke", "noAccess");
+pref("capability.policy.mailnews.SOAPResponse.fault", "noAccess");
+pref("capability.policy.mailnews.SOAPEncoding.styleURI", "noAccess");
+pref("capability.policy.mailnews.SOAPEncoding.getAssociatedEncoding", "noAccess");
+pref("capability.policy.mailnews.SOAPEncoding.setEncoder", "noAccess");
+pref("capability.policy.mailnews.SOAPEncoding.getEncoder", "noAccess");
+pref("capability.policy.mailnews.SOAPEncoding.setDecoder", "noAccess");
+pref("capability.policy.mailnews.SOAPEncoding.setDecoder", "noAccess");
+pref("capability.policy.mailnews.SOAPEncoding.getDecoder", "noAccess");
+pref("capability.policy.mailnews.SOAPEncoding.defaultEncoder", "noAccess");
+pref("capability.policy.mailnews.SOAPEncoding.defaultDecoder", "noAccess");
+pref("capability.policy.mailnews.SOAPEncoding.schemaCollection", "noAccess");
+pref("capability.policy.mailnews.SOAPEncoding.encode", "noAccess");
+pref("capability.policy.mailnews.SOAPEncoding.decode", "noAccess");
+pref("capability.policy.mailnews.SOAPEncoding.mapSchemaURI", "noAccess");
+pref("capability.policy.mailnews.SOAPEncoding.unmapSchemaURI", "noAccess");
+pref("capability.policy.mailnews.SOAPEncoding.getInternalSchemaURI", "noAccess");
+pref("capability.policy.mailnews.SOAPEncoding.getExternalSchemaURI", "noAccess");
+pref("capability.policy.mailnews.SOAPFault.element", "noAccess");
+pref("capability.policy.mailnews.SOAPFault.faultNamespaceURI", "noAccess");
+pref("capability.policy.mailnews.SOAPFault.faultCode", "noAccess");
+pref("capability.policy.mailnews.SOAPFault.faultString", "noAccess");
+pref("capability.policy.mailnews.SOAPFault.faultActor", "noAccess");
+pref("capability.policy.mailnews.SOAPFault.detail", "noAccess");
+pref("capability.policy.mailnews.SOAPHeaderBlock.actorURI", "noAccess");
+pref("capability.policy.mailnews.SOAPHeaderBlock.mustUnderstand", "noAccess");
+pref("capability.policy.mailnews.SOAPParameter", "noAccess");
+pref("capability.policy.mailnews.SOAPPropertyBagMutator.propertyBag", "noAccess");
+pref("capability.policy.mailnews.SOAPPropertyBagMutator.addProperty", "noAccess");
+pref("capability.policy.mailnews.SchemaLoader.load", "noAccess");
+pref("capability.policy.mailnews.SchemaLoader.loadAsync", "noAccess");
+pref("capability.policy.mailnews.SchemaLoader.processSchemaElement", "noAccess");
+pref("capability.policy.mailnews.SchemaLoader.onLoad", "noAccess");
+pref("capability.policy.mailnews.SchemaLoader.onError", "noAccess");
+pref("capability.policy.mailnews.WSDLLoader.load", "noAccess");
+pref("capability.policy.mailnews.WSDLLoader.loadAsync", "noAccess");
+pref("capability.policy.mailnews.WSDLLoader.onLoad", "noAccess");
+pref("capability.policy.mailnews.WSDLLoader.onError", "noAccess");
+pref("capability.policy.mailnews.WebServiceProxyFactory.createProxy", "noAccess");
+pref("capability.policy.mailnews.WebServiceProxyFactory.createProxyAsync", "noAccess");
+pref("capability.policy.mailnews.WebServiceProxyFactory.onLoad", "noAccess");
+pref("capability.policy.mailnews.WebServiceProxyFactory.onError", "noAccess");
+
+// XMLExtras
+pref("capability.policy.default.XMLHttpRequest.channel", "noAccess");
+pref("capability.policy.default.DOMParser.parseFromStream", "noAccess");
+
+// Clipboard
+pref("capability.policy.default.Clipboard.cutcopy", "noAccess");
+pref("capability.policy.default.Clipboard.paste", "noAccess");
 
 // Scripts & Windows prefs
 pref("browser.block.target_new_window",     false);
 pref("dom.disable_cookie_get",              false);
 pref("dom.disable_cookie_set",              false);
 pref("dom.disable_image_src_set",           false);
-pref("dom.disable_open_during_load",        false);
 pref("dom.disable_window_flip",             false);
 pref("dom.disable_window_move_resize",      false);
 pref("dom.disable_window_status_change",    false);
 
+pref("dom.disable_window_open_feature.titlebar",    false);
+pref("dom.disable_window_open_feature.close",       false);
+pref("dom.disable_window_open_feature.toolbar",     false);
+pref("dom.disable_window_open_feature.location",    false);
+pref("dom.disable_window_open_feature.directories", false);
+pref("dom.disable_window_open_feature.personalbar", false);
+pref("dom.disable_window_open_feature.menubar",     false);
+pref("dom.disable_window_open_feature.scrollbars",  false);
+pref("dom.disable_window_open_feature.resizable",   false);
+pref("dom.disable_window_open_feature.minimizable", false);
+pref("dom.disable_window_open_feature.status",      false);
+
+pref("dom.allow_scripts_to_close_windows",          false);
+
 pref("javascript.enabled",                  true);
 pref("javascript.allow.mailnews",           false);
 pref("javascript.options.strict",           false);
@@ -370,7 +477,6 @@ pref("javascript.options.showInConsole",    true);
 // advanced prefs
 pref("advanced.always_load_images",         true);
 pref("security.enable_java",                true);
-pref("css.allow",                           true);
 pref("advanced.mailftp",                    false);
 pref("image.animation_mode",                "normal");
 
@@ -378,7 +484,6 @@ pref("offline.startup_state",            0);
 pref("offline.send.unsent_messages",            0);
 pref("offline.download.download_messages",  0);
 pref("offline.prompt_synch_on_exit",            true);
-pref("offline.news.download.use_days",          0);
 
 // If there is ever a security firedrill that requires
 // us to block certian ports global, this is the pref 
@@ -388,6 +493,13 @@ pref("offline.news.download.use_days",          0);
 // prevents necko connecting to ports 1-5 unless the protocol
 // overrides.
 
+// Prevent using external protocol handlers for these schemes
+pref("network.protocol-handler.external.hcp", false);
+pref("network.protocol-handler.external.vbscript", false);
+pref("network.protocol-handler.external.javascript", false);
+pref("network.protocol-handler.external.ms-help", false);
+pref("network.protocol-handler.external.vnd.ms.radio", false);
+
 pref("network.hosts.smtp_server",           "mail");
 pref("network.hosts.pop_server",            "mail");
 pref("network.protocols.useSystemDefaults",   false); // set to true if user links should use system default handlers
@@ -406,6 +518,10 @@ pref("network.http.proxy.version", "1.1");    // default
 // enable caching of http documents
 pref("network.http.use-cache", true);
 
+// this preference can be set to override the socket type used for normal
+// HTTP traffic.  an empty value indicates the normal TCP/IP socket type.
+pref("network.http.default-socket-type", "");
+
 pref("network.http.keep-alive", true); // set it to false in case of problems
 pref("network.http.proxy.keep-alive", true);
 pref("network.http.keep-alive.timeout", 300);
@@ -439,15 +555,20 @@ pref("network.http.connect.timeout",  30);	// in seconds
 pref("network.http.request.timeout", 120);	// in seconds
 
 // Headers
-pref("network.http.accept.default", "text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,video/x-mng,image/png,image/jpeg,image/gif;q=0.2,text/css,*/*;q=0.1");
+pref("network.http.accept.default", "text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,video/x-mng,image/png,image/jpeg,image/gif;q=0.2,*/*;q=0.1");
 
 pref("network.http.sendRefererHeader",      2); // 0=don't send any, 1=send only on clicks, 2=send on image requests as well
 
+// Controls whether we send HTTPS referres to other HTTPS sites.
+// By default this is enabled for compatibility (see bug 141641)
+pref("network.http.sendSecureXSiteReferrer", true);
+
 // Maximum number of consecutive redirects before aborting.
-pref("network.http.redirection-limit", 10);
+pref("network.http.redirection-limit", 20);
 
 // Enable http compression: comment this out in case of problems with 1.1
-pref("network.http.accept-encoding" ,"gzip, deflate, compress;q=0.9");
+// NOTE: support for "compress" has been disabled per bug 196406.
+pref("network.http.accept-encoding" ,"gzip,deflate");
 
 pref("network.http.pipelining"      , false);
 pref("network.http.proxy.pipelining", false);
@@ -480,6 +601,9 @@ pref("network.ftp.idleConnectionTimeout", 300);
 // Do not set this to 0...
 pref("network.dir.format", 2);
 
+// enables the prefetch service (i.e., prefetching of <link rel="next"> URLs).
+pref("network.prefetch-next", true);
+
 // sspitzer:  change this back to "news" when we get to beta.
 // for now, set this to news.mozilla.org because you can only
 // post to the server specified by this pref.
@@ -507,10 +631,8 @@ pref("network.proxy.ssl_port",              0);
 pref("network.proxy.socks",                 "");
 pref("network.proxy.socks_port",            0);
 pref("network.proxy.socks_version",         5);
-pref("network.proxy.no_proxies_on",         "");
+pref("network.proxy.no_proxies_on",         "localhost, 127.0.0.1");
 pref("network.online",                      true); //online/offline
-pref("network.accept_cookies",              0);     // 0 = Always, 1 = warn, 2 = never
-pref("network.foreign_cookies",             0); // 0 = Accept, 1 = Don't accept
 pref("network.cookie.cookieBehavior",       3); // 0-Accept, 1-dontAcceptForeign, 2-dontUse, 3-p3p
 pref("network.cookie.disableCookieForMailNews", true); // disable all cookies for mail
 pref("network.cookie.warnAboutCookies",     false);
@@ -630,6 +752,8 @@ pref("profile.confirm_automigration",true);
 // if -1, we never think your profile is defunct
 // and users will never see the remigrate UI.
 pref("profile.seconds_until_defunct", -1);
+// We can show it anytime from menus
+pref("profile.manage_only_at_launch", false);
 
 // Customizable toolbar stuff
 pref("custtoolbar.personal_toolbar_folder", "");
@@ -661,7 +785,7 @@ pref("bidi.texttype", 1);
 //  Controls Text Mode
 // ------------------
 // 1 = logicalcontrolstextmodeBidiCmd
-// 2 = visiualcontrolstextmodeBidi
+// 2 = visualcontrolstextmodeBidi <-- NO LONGER SUPPORTED
 // 3 = containercontrolstextmodeBidi *
 pref("bidi.controlstextmode", 1);
 // ------------------
@@ -674,11 +798,12 @@ pref("bidi.clipboardtextmode", 3);
 // ------------------
 //  Numeral Style
 // ------------------
-// 1 = regularcontextnumeralBidi *
+// 0 = nominalnumeralBidi *
+// 1 = regularcontextnumeralBidi
 // 2 = hindicontextnumeralBidi
 // 3 = arabicnumeralBidi
 // 4 = hindinumeralBidi
-pref("bidi.numeral", 1);
+pref("bidi.numeral", 0);
 // ------------------
 //  Support Mode
 // ------------------
@@ -717,11 +842,27 @@ pref("update_notifications.enabled", true);
 pref("update_notifications.provider.0.frequency", 7); // number of days
 pref("update_notifications.provider.0.datasource", "chrome://communicator-region/locale/region.properties");
 
+// 0 opens the download manager
+// 1 opens a progress dialog
+// 2 and other values, no download manager, no progress dialog. 
 pref("browser.downloadmanager.behavior", 0);
 
 // if true, allow plug-ins to override internal imglib decoder mime types in full-page mode
 pref("plugin.override_internal_types", false);
+pref("plugin.expose_full_path", false); // if true navigator.plugins reveals full path
 
 // See bug 136985.  Gives embedders a pref to hook into to show
 // a popup blocker if they choose.
 pref("browser.popups.showPopupBlocker", true);
+
+// Pref to control whether the viewmanager code does double-buffering or not
+// See http://bugzilla.mozilla.org/show_bug.cgi?id=169483 for further details...
+pref("viewmanager.do_doublebuffering", true);
+
+pref("dom.disable_open_during_load",              false);
+pref("privacy.popups.first_popup",                true);
+pref("privacy.popups.sound_enabled",              false);
+pref("privacy.popups.sound_url",                  "");
+pref("privacy.popups.statusbar_icon_enabled",     true);
+pref("privacy.popups.prefill_whitelist",          false);
+pref("privacy.popups.remove_blacklist",           true);
